Example uses of Thermo
======================

The following Jupyter notebooks show some of the many calculations that can be done with Thermo.

These problems often make use of `fluids <https://github.com/CalebBell/fluids>`_,  `ht <https://github.com/CalebBell/ht>`_,  `chemicals <https://github.com/CalebBell/chemicals>`_, and `pint <https://github.com/hgrecco/pint/>`_ so make sure you have them installed!
More details on the unit handling library can be found at :doc:`fluids.units <fluids.units>`.


.. toctree::
    Examples/Working with Heat Transfer Fluids - Therminol LT.ipynb
    Examples/Validating Flash Calculations.ipynb
    Examples/High Molecular Weight Petroleum Pseudocomponents.ipynb
    Examples/Performing Large Numbers of Calculations with Thermo in Parallel.ipynb